// Constants for Google Sheets API
const spreadsheetId = '11LY8SkwB_q_ccibbi_im1SkZJcZvrgN3Md7rnJHt6TI';
const API_key = 'AIzaSyACI1H2zJYGw_f0lzV9K0BA30SBw6vi03E';

// Construct the URL for the API request to read the entire sheet
const url = `https://sheets.googleapis.com/v4/spreadsheets/${spreadsheetId}/values/UserDatabase?majorDimension=ROWS&valueRenderOption=FORMATTED_VALUE&dateTimeRenderOption=FORMATTED_STRING&key=${API_key}`;

document.addEventListener('DOMContentLoaded', function () {
    displaySavedInfo(); // Display saved info when popup loads

    // Save button event listener
    document.getElementById('submit-btn').addEventListener('click', async function () {
        const userId = document.getElementById('ext-login').value;
        const password = document.getElementById('ext-password').value;
        const clickSpeed = document.getElementById('click-speed').value;
        const aadhaarNumber = document.getElementById('aadhaar-number').value;

        console.log('Save button clicked. Checking user credentials...'); // Debugging log

        // Check user credentials
        const isAuthenticated = await checkUser(userId, password);

        if (isAuthenticated) {
            console.log('User authenticated successfully! Saving data...');

            // Save user credentials and click speed
            chrome.storage.local.set({ userId: userId, password: password, clickSpeed: clickSpeed, aadhaarNumber: aadhaarNumber }, function () {
                alert('User ID, password, click speed, and Aadhaar number saved successfully!');
                displaySavedInfo(); // Display updated info
            });
        } else {
            alert('Invalid User ID or Password! Cannot save.');
        }
    });

    // Check NPCI button event listener
    document.getElementById('check-npci-btn').addEventListener('click', async function () {
        const userId = document.getElementById('ext-login').value;
        const password = document.getElementById('ext-password').value;

        console.log('Check NPCI button clicked. Checking user credentials...'); // Debugging log

        // Check user credentials
        const isAuthenticated = await checkUser(userId, password);

        if (isAuthenticated) {
            alert('User authenticated successfully!');
            console.log('User authenticated, starting button click automation...');

            const clickSpeed = parseInt(document.getElementById('click-speed').value) * 1000; // Convert to milliseconds

            if (clickSpeed < 1000 || clickSpeed > 900000) {
                alert('Please enter a speed between 1 and 900 seconds.');
                return;
            }

            // Inject script into the active tab to continuously click the submit button
            injectScriptIntoTab(clickSpeed);
        } else {
            alert('Invalid User ID or Password! Cannot proceed.');
        }
    });

    // Listen for page reloads and reinject the script
    chrome.tabs.onUpdated.addListener(function (tabId, changeInfo, tab) {
        if (changeInfo.status === 'complete' && tab.active) {
            // Reinject the script after the page reloads
            chrome.storage.local.get(['clickSpeed'], function (result) {
                const clickSpeed = result.clickSpeed || 1000; // Default to 1 second if not set
                injectScriptIntoTab(clickSpeed);
            });
        }
    });

    // Check user credentials using Google Sheets
    async function checkUser(inputUsername, inputPassword) {
        try {
            console.log('Checking user in Google Sheets...'); // Debugging log

            const response = await fetch(url);
            const data = await response.json();
            const users = data.values;

            const headers = users[0];
            const usernameIndex = headers.indexOf('nusername');
            const passwordIndex = headers.indexOf('password');

            if (usernameIndex === -1 || passwordIndex === -1) {
                console.error('nusername or password column not found');
                return false;
            }

            for (let i = 1; i < users.length; i++) {
                const user = users[i];
                const username = user[usernameIndex];
                const password = user[passwordIndex];

                if (username === inputUsername && password === inputPassword) {
                    console.log('User authenticated'); // Debugging log
                    return true;
                }
            }
            console.log('User not found in Google Sheets');
            return false;
        } catch (error) {
            console.error('Error fetching data:', error);
            return false;
        }
    }

    // Display saved information
    function displaySavedInfo() {
        chrome.storage.local.get(['userId', 'password', 'clickSpeed', 'aadhaarNumber'], function (result) {
            document.getElementById('ext-login').value = result.userId || '';
            document.getElementById('ext-password').value = result.password || '';
            document.getElementById('click-speed').value = result.clickSpeed || '1'; // Set default click speed
            document.getElementById('aadhaar-number').value = result.aadhaarNumber || '';
            console.log(`UserId: ${result.userId || 'Not set'}, Password: ${result.password || 'Not set'}, Click Speed: ${result.clickSpeed || '1'}`);
        });
    }



   // Aadhaar submit button event listener
document.getElementById('submit-aadhaar-btn').addEventListener('click', async function () {
    const aadhaarNumber = document.getElementById('aadhaar-number').value;
    const userId = document.getElementById('ext-login').value;
    const password = document.getElementById('ext-password').value;

    if (!aadhaarNumber) {
        alert('Please enter Aadhaar number before submitting!');
        return;
    }

    // Save Aadhaar number in local storage
    chrome.storage.local.set({ aadhaarNumber: aadhaarNumber }, async function () {
        console.log('Aadhaar number saved.');

        // Authenticate the user after saving Aadhaar
        const isAuthenticated = await checkUser(userId, password);
        if (isAuthenticated) {
            alert('Aadhaar submitted successfully and user authenticated!');

            // Find Aadhaar input fields, auto-click the submit button, and tick the radio button
            chrome.tabs.query({ active: true, currentWindow: true }, function (tabs) {
                chrome.scripting.executeScript({
                    target: { tabId: tabs[0].id },
                    func: fillAadhaarAndSubmitAndTick,
                    args: [aadhaarNumber]
                }, () => {
                    console.log('Aadhaar number filled, radio button ticked, and submit button clicked.');
                });
            });
        } else {
            alert('Authentication failed. Please check your credentials.');
        }
    });
});

// Function to fill Aadhaar, tick the radio button, and click the submit button
function fillAadhaarAndSubmitAndTick(aadhaarNumber) {
    const aadhar1Field = document.getElementById('ContentPlaceHolder1_txtadharno');
    const aadhar2Field = document.getElementById('ContentPlaceHolder1_txtadharno_Re');
    const submitButton2 = document.getElementById('ContentPlaceHolder1_btn_submit');
    const agreeCheckbox = document.getElementById('ContentPlaceHolder1_chkIAgry');
    
    if (aadhar1Field && aadhar2Field) {
        aadhar1Field.value = aadhaarNumber;
        aadhar2Field.value = aadhaarNumber;
        console.log('Aadhaar number filled in both fields.');





        

        // Automatically tick the checkbox/radio button
        if (agreeCheckbox) {
            agreeCheckbox.checked = true;
            console.log('Checkbox/radio button ticked.');
        } else {
            console.error('Checkbox/radio button not found!');
        }

        // Automatically click the submit button after Aadhaar fields are filled and checkbox is ticked
        if (submitButton2) {
            submitButton2.click();
            console.log('Submit button clicked!');
        } else {
            console.error('Submit button not found!');
        }
    } else {
        console.error('Aadhaar input fields not found!');
    }
}


    // Function to inject the clicking script into the active tab
    function injectScriptIntoTab(clickSpeed) {
        chrome.tabs.query({ active: true, currentWindow: true }, function (tabs) {
            console.log('Injecting script to tab with ID:', tabs[0].id); // Debugging log

            chrome.scripting.executeScript({
                target: { tabId: tabs[0].id },
                func: continuouslyClickSubmitButtonOrTriggerNPCI,
                args: [clickSpeed] // Passing the click speed
            }, () => {
                console.log("Script injected, submit button clicking initiated.");
            });
        });
    }
});

// Function to continuously click buttons
function continuouslyClickSubmitButtonOrTriggerNPCI(clickSpeed) {
    console.log('Starting button click automation...');

    const submitButtonSelector = '#ContentPlaceHolder1_btn_submit'; // Adjust the selector as necessary
    const npcicheckButtonSelector = '#check-npci-btn'; // Adjust the selector as necessary

    let clickingEnabled = true; // Flag to manage clicking state
    let intervalId; // Store the interval ID to clear it later

    // Function to click buttons
    const clickButtons = () => {
        if (!clickingEnabled) {
            console.log('Clicking is disabled. Stopping automation.');
            clearInterval(intervalId); // Clear the interval if clicking is disabled
            return;
        }

        const submitButton = document.querySelector(submitButtonSelector);
        const npcicheckButton = document.querySelector(npcicheckButtonSelector);

        if (submitButton) {
            submitButton.click();
            console.log('Submit button clicked!');
        } else if (npcicheckButton) {
            npcicheckButton.click();
            console.log('NPCI button clicked!');
        } else {
            console.log('No buttons found!');
        }
    };

    // Immediately check for buttons and click if found
    clickButtons();

    // Set up MutationObserver to look for button additions
    const observer = new MutationObserver(() => {
        const submitButton = document.querySelector(submitButtonSelector);
        const npcicheckButton = document.querySelector(npcicheckButtonSelector);

        if (submitButton || npcicheckButton) {
            console.log('Button found! Starting interval...');

            // Start clicking at the specified interval
            intervalId = setInterval(() => {
                clickButtons();
            }, clickSpeed); // This now uses the speed in milliseconds

            // Stop observing once the button is found and the interval is set
            observer.disconnect();
        }
    });

    // Start observing the body for changes
    observer.observe(document.body, { childList: true, subtree: true });

    // Listen for page unloads and clear interval on load
    window.addEventListener('beforeunload', () => {
        clickingEnabled = false; // Disable clicking
        clearInterval(intervalId); // Clear the interval
        console.log('Page unloading. Automation stopped.');
    });
}
